=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-10-11 03:27:29 +0000
+++ bzrlib/branch.py	2005-10-12 11:01:25 +0000
@@ -91,27 +91,6 @@
     return os.sep.join(s)
         
 
-def find_branch_root(t):
-    """Find the branch root enclosing the transport's base.
-
-    t is a Transport object.
-
-    It is not necessary that the base of t exists.
-
-    Basically we keep looking up until we find the control directory or
-    run into the root.  If there isn't one, raises NotBranchError.
-    """
-    orig_base = t.base
-    while True:
-        if t.has(bzrlib.BZRDIR):
-            return t
-        new_t = t.clone('..')
-        if new_t.base == t.base:
-            # reached the root, whatever that may be
-            raise NotBranchError('%s is not in a branch' % orig_base)
-        t = new_t
-
-
 ######################################################################
 # branch objects
 
@@ -145,10 +124,21 @@
         """Open an existing branch which contains url.
         
         This probes for a branch at url, and searches upwards from there.
+
+        Basically we keep looking up until we find the control directory or
+        run into the root.  If there isn't one, raises NotBranchError.
         """
         t = get_transport(url)
-        t = find_branch_root(t)
-        return _Branch(t)
+        while True:
+            try:
+                return _Branch(t)
+            except NotBranchError:
+                pass
+            new_t = t.clone('..')
+            if new_t.base == t.base:
+                # reached the root, whatever that may be
+                raise NotBranchError('%s is not in a branch' % url)
+            t = new_t
 
     @staticmethod
     def initialize(base):

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-10-11 04:13:14 +0000
+++ bzrlib/builtins.py	2005-10-12 11:01:25 +0000
@@ -461,7 +461,6 @@
     
     def run(self, branch=None):
         import info
-
         b = Branch.open_containing(branch)
         info.show_info(b)
 

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2005-10-04 04:37:29 +0000
+++ bzrlib/transport/local.py	2005-10-12 11:01:25 +0000
@@ -74,8 +74,8 @@
             path = self.abspath(relpath)
             return open(path, 'rb')
         except IOError,e:
-            if e.errno == errno.ENOENT:
-                raise NoSuchFile('File %r does not exist' % path, orig_error=e)
+            if e.errno in (errno.ENOENT, errno.ENOTDIR):
+                raise NoSuchFile('File or directory %r does not exist' % path, orig_error=e)
             raise LocalTransportError(orig_error=e)
 
     def get_partial(self, relpath, start, length=None):

